#ifndef _Z_H
#define _Z_H

double poz (double z);                 
double critz (double p);       

#endif

